import { Decoder, Address } from '@solana/web3.js';
import { TCollection, TUses } from '../../shared-types';
import type { TCreator } from './metadataArgsEncoder';
declare enum TTokenStandardWithProgrammable {
    NonFungible = 0,
    FungibleAsset = 1,
    Fungible = 2,
    NonFungibleEdition = 3,
    ProgrammableNonFungible = 4
}
declare enum Key {
    Uninitialized = 0,
    EditionV1 = 1,
    MasterEditionV1 = 2,
    ReservationListV1 = 3,
    MetadataV1 = 4,
    ReservationListV2 = 5,
    MasterEditionV2 = 6,
    EditionMarker = 7,
    UseAuthorityRecord = 8,
    CollectionAuthorityRecord = 9,
    TokenOwnedEscrow = 10,
    TokenRecord = 11,
    MetadataDelegate = 12,
    EditionMarkerV2 = 13
}
export type MetadataData = {
    name: string;
    symbol: string;
    uri: string;
    sellerFeeBasisPoints: number;
    creators: TCreator[] | null;
};
export type ProgrammableConfigRecord = {
    ruleSet: Address | null;
};
export type ProgrammableConfig = ProgrammableConfigRecord & {
    __kind: 'V1';
};
export type CollectionDetails = {
    __kind: 'V1';
    size: bigint;
} | {
    __kind: 'V2';
    padding: Array<number>;
};
export type Metadata = {
    key: Key;
    updateAuthority: Address;
    mint: Address;
    data: MetadataData;
    primarySaleHappened: boolean;
    isMutable: boolean;
    editionNonce: number | null;
    tokenStandard: TTokenStandardWithProgrammable | null;
    collection: TCollection | null;
    uses: TUses | null;
    collectionDetails: CollectionDetails | null;
    programmableConfig: ProgrammableConfig | null;
};
export declare function getMetadataDecoder(): Decoder<Metadata>;
export declare function getCollectionDetailsDecoder(): Decoder<CollectionDetails>;
export declare function getProgrammableConfigDecoder(): Decoder<ProgrammableConfig>;
export declare function getProgrammableConfigRecordDecoder(): Decoder<ProgrammableConfigRecord>;
export declare function getMetadataDataDecoder(): Decoder<MetadataData>;
export declare function getTCreatorDecoder(): Decoder<TCreator>;
export {};
//# sourceMappingURL=metadataDecoder.d.ts.map